==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebDimensionsChangeEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDimensionsChangeDetailDescriptionMetadata } from "./WebDimensionsChangeDetailDescriptionMetadata";
import { WebDimensionsChangeEventArgsDescription } from "./WebDimensionsChangeEventArgsDescription";
/**
 * @hidden
 */
export let WebDimensionsChangeEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebDimensionsChangeEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebDimensionsChangeEventArgsDescriptionMetadata.a == null) {
                WebDimensionsChangeEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebDimensionsChangeEventArgsDescriptionMetadata.c(WebDimensionsChangeEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebDimensionsChangeEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebDimensionsChangeEventArgsDescriptionMetadata.a);
            WebDimensionsChangeDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:DimensionsChangeEventArgs");
            a.item("Detail", "ExportedType:WebDimensionsChangeDetail");
        }
        static d(a) {
            WebDimensionsChangeEventArgsDescriptionMetadata.b(a);
            a.ad("WebDimensionsChangeEventArgs", () => new WebDimensionsChangeEventArgsDescription());
            a.ac("WebDimensionsChangeEventArgs", WebDimensionsChangeEventArgsDescriptionMetadata.a);
        }
    }
    WebDimensionsChangeEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebDimensionsChangeEventArgsDescriptionMetadata, 'WebDimensionsChangeEventArgsDescriptionMetadata');
    WebDimensionsChangeEventArgsDescriptionMetadata.a = null;
    return WebDimensionsChangeEventArgsDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/WebDimensionsChangeEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDimensionsChangeDetailDescriptionMetadata } from "./WebDimensionsChangeDetailDescriptionMetadata";
import { WebDimensionsChangeEventArgsDescription } from "./WebDimensionsChangeEventArgsDescription";
/**
 * @hidden
 */
export let WebDimensionsChangeEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebDimensionsChangeEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebDimensionsChangeEventArgsDescriptionMetadata.a == null) {
                WebDimensionsChangeEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebDimensionsChangeEventArgsDescriptionMetadata.c(WebDimensionsChangeEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebDimensionsChangeEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebDimensionsChangeEventArgsDescriptionMetadata.a);
            WebDimensionsChangeDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:DimensionsChangeEventArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("Detail", "ExportedType:WebDimensionsChangeDetail");
        }
        static d(a) {
            WebDimensionsChangeEventArgsDescriptionMetadata.b(a);
            a.ae("WebDimensionsChangeEventArgs", () => new WebDimensionsChangeEventArgsDescription());
            a.ad("WebDimensionsChangeEventArgs", WebDimensionsChangeEventArgsDescriptionMetadata.a);
        }
    }
    WebDimensionsChangeEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebDimensionsChangeEventArgsDescriptionMetadata, 'WebDimensionsChangeEventArgsDescriptionMetadata');
    WebDimensionsChangeEventArgsDescriptionMetadata.a = null;
    return WebDimensionsChangeEventArgsDescriptionMetadata;
})();
